@@ -102,7 +102,7 @@ sub ApplyLimits {
     if ( $per_page) {
         $limit_clause = " LIMIT ";
         $limit_clause .= $per_page;
-        if ( $first != 0 ) {
+        if ( $first && $first != 0 ) {
             $limit_clause .= " OFFSET $first";
         }
     }
@@ -249,5 +249,34 @@ sub _BuildJoins {
                     join ( ", ", ($join_clause, @{ $sb->{'aliases'} }))) ;
 
 }
+# {{{ _MakeClauseCaseInsensitive
 
+=head2 _MakeClauseCaseInsensitive FIELD OPERATOR VALUE
+
+Takes a field, operator and value. performs the magic necessary to make
+your database treat this clause as case insensitive.
+
+Returns a FIELD OPERATOR VALUE triple.
+
+=cut
+
+sub _MakeClauseCaseInsensitive {
+    my $self = shift;
+    my $field = shift;
+    my $operator = shift;
+    my $value = shift;
+ 
+
+
+    if  ($operator =~ /LIKE/i ) {
+        $operator =~ s/LIKE/ILIKE/ig; 
+        return ($field, $operator, $value);
+    } elsif ($operator =~ /\s*=\s*/) {
+        return ($field,'ILIKE',$value);
+    } else {
+        $self->SUPER::_MakeClauseCaseInsensitive($field, $operator,$value);
+    }
+}
+
+# }}}
 1;
